/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { OperationOptions } from "retry";
export declare namespace Campaigns {
  type CampaignSearchResult = {
    hits: Array<Campaign>;
    query: any;
    sorts?: Array<Sort>;
    limit: number;
    offset: any;
    total: any;
  } & {
    [key: string]: any;
  };
  type Campaign = {
    campaignId?: string;
    coupons?: Array<string>;
    creationDate?: any;
    customerGroups?: Array<string>;
    description?: string;
    enabled?: boolean;
    endDate?: any;
    lastModified?: any;
    sourceCodeGroups?: Array<string>;
    startDate?: any;
    siteId?: string;
  } & {
    [key: string]: any;
  };
  type Money = {
    currencyMnemonic?: string;
    value?: number;
  } & {
    [key: string]: any;
  };
  type SimpleSearchResult = {
    limit: number;
    hits?: Array<object>;
    offset: any;
    total: any;
  } & {
    [key: string]: any;
  };
  type SearchRequest = {
    limit?: number;
    query: any;
    sorts?: Array<Sort>;
    offset?: any;
  } & {
    [key: string]: any;
  };
  type PaginatedSearchResult = {
    query: any;
    sorts?: Array<Sort>;
    limit: number;
    hits?: Array<object>;
    offset: any;
    total: any;
  } & {
    [key: string]: any;
  };
  type ClosedObject = {} & {
    [key: string]: any;
  };
  type OpenObject = {} & {
    [key: string]: any;
  };
  type BoolFilter = {
    filters?: Array<any>;
    operator: string;
  } & {
    [key: string]: any;
  };
  type PaginatedSearchResultBase = {
    query: any;
    sorts?: Array<Sort>;
    limit: number;
    hits?: Array<object>;
    offset: any;
    total: any;
  } & {
    [key: string]: any;
  };
  type MatchAllQuery = {} & {
    [key: string]: any;
  };
  type FilteredQuery = {
    filter: any;
    query: any;
  } & {
    [key: string]: any;
  };
  type QueryFilter = {
    query: any;
  } & {
    [key: string]: any;
  };
  type Query = {
    boolQuery?: BoolQuery;
    filteredQuery?: FilteredQuery;
    matchAllQuery?: MatchAllQuery;
    nestedQuery?: NestedQuery;
    termQuery?: TermQuery;
    textQuery?: TextQuery;
  } & {
    [key: string]: any;
  };
  type TermQuery = {
    fields: Array<string>;
    operator: string;
    values?: Array<any>;
  } & {
    [key: string]: any;
  };
  type TermFilter = {
    field: string;
    operator: string;
    values?: Array<any>;
  } & {
    [key: string]: any;
  };
  type TextQuery = {
    fields: Array<string>;
    searchPhrase: string;
  } & {
    [key: string]: any;
  };
  type Range2Filter = {
    filterMode?: string;
    fromField: string;
    fromInclusive?: boolean;
    fromValue?: any;
    toField: string;
    toInclusive?: boolean;
    toValue?: any;
  } & {
    [key: string]: any;
  };
  type BoolQuery = {
    must?: Array<any>;
    mustNot?: Array<any>;
    should?: Array<any>;
  } & {
    [key: string]: any;
  };
  type SimpleSearchResultBase = {
    limit: number;
    hits?: Array<object>;
    offset: any;
    total: any;
  } & {
    [key: string]: any;
  };
  type NestedQuery = {
    path: string;
    query: any;
    scoreMode?: string;
  } & {
    [key: string]: any;
  };
  type Filter = {
    boolFilter?: BoolFilter;
    queryFilter?: QueryFilter;
    range2Filter?: Range2Filter;
    rangeFilter?: RangeFilter;
    termFilter?: TermFilter;
  } & {
    [key: string]: any;
  };
  type Sort = {
    field: string;
    sortOrder?: string;
  } & {
    [key: string]: any;
  };
  type RangeFilter = {
    field: string;
    from?: any;
    fromInclusive?: boolean;
    to?: any;
    toInclusive?: boolean;
  } & {
    [key: string]: any;
  };
  type SearchRequestBase = {
    limit?: number;
    query: any;
    sorts?: Array<Sort>;
    offset?: any;
  } & {
    [key: string]: any;
  };
  type NoPropertiesAllowed = {};
  type SpecifiedPropertiesAllowed = {} & {
    [key: string]: any;
  };
  type MoneyMnemonic = {
    currencyMnemonic?: string;
    value?: number;
  } & {
    [key: string]: any;
  };
  type ErrorResponse = {
    type: string;
    title?: string;
    detail?: string;
    instance?: string;
  } & {
    [key: string]: any;
  };
}
/**
* [Campaigns](https://developer.commercecloud.com/s/api-details/a003k00000UHvobAAD)
* ==================================
*
* *Utilize campaign experiences for your customers.*<br />
*
* Simple example:
*
* ```typescript
*   import { Pricing, ClientConfig } from "commerce-sdk";
*   // or
*   const { Pricing, ClientConfig } = require("commerce-sdk");
*
*   const clientConfig: ClientConfig = { ... };
*   const campaignsClient = new Pricing.Campaigns(clientConfig);
* ```
*
* Example with shopper auth
* ```typescript
* const clientConfig: ClientConfig = {
*   parameters: {
*     clientId: "XXXXXX",
*     organizationId: "XXXX",
*     shortCode: "XXX",
*     siteId: "XX"
*   }
* };
* token = await helpers.getShopperToken(clientConfig, { type: "guest" });
* clientConfig.headers["authorization"] = token.getBearerHeader();
* const campaignsClient = new Pricing.Campaigns(clientConfig);
* ```
*
* <span style="font-size:.7em; display:block; text-align: right">
* API Version: 1.0.18<br />
* Last Updated: 2020-07-16T20:27:34.749Z<br />
* </span>

*

*/
export declare class Campaigns extends BaseClient {
  constructor(config: ClientConfig);
  /**
    * Searches for campaigns using a search request object that allows filtering on various attributes.

  ## Supported Query Attributes

  The query attribute specifies a complex query that can be used to narrow down the search. A subset of these can optionally be used to sort the returned results.

  | Attribute | Type | Sortable |
  |-----------|--------|----------|
  | campaignId | String | yes |
  | description | String | yes |
  | enabled | Boolean | yes |
  | couponId | String | no |
  | customerGroup | String | no |
  | sourceCode | String | no |
  | startDate | Date | no |
  | endDate | Date | no |
  | lastModified | Date | no |

  These fields can only be used in queries as conjunctions (using `AND`). If the field is used in a disjunction (`OR`), an exception is thrown.
    *
    * If you would like to get a raw Response object use the other campaignsSearch function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type Campaigns.CampaignSearchResult.
    *
    */
  campaignsSearch(options: {
    parameters?: {
      organizationId?: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: Campaigns.SearchRequest;
  }): Promise<Campaigns.CampaignSearchResult>;
  /**
    * Searches for campaigns using a search request object that allows filtering on various attributes.

  ## Supported Query Attributes

  The query attribute specifies a complex query that can be used to narrow down the search. A subset of these can optionally be used to sort the returned results.

  | Attribute | Type | Sortable |
  |-----------|--------|----------|
  | campaignId | String | yes |
  | description | String | yes |
  | enabled | Boolean | yes |
  | couponId | String | no |
  | customerGroup | String | no |
  | sourceCode | String | no |
  | startDate | Date | no |
  | endDate | Date | no |
  | lastModified | Date | no |

  These fields can only be used in queries as conjunctions (using `AND`). If the field is used in a disjunction (`OR`), an exception is thrown.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type Campaigns.CampaignSearchResult otherwise.
    *
    */
  campaignsSearch<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: Campaigns.SearchRequest;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : Campaigns.CampaignSearchResult>;
  /**
   * Deletes the campaign by ID.
   *
   * If you would like to get a raw Response object use the other deleteCampaign function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param campaignId - The ID of the campaign.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   *
   */
  deleteCampaign(options?: {
    parameters?: {
      organizationId?: string;
      campaignId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Deletes the campaign by ID.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param campaignId - The ID of the campaign.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  deleteCampaign<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        campaignId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Action to get campaign information.
   *
   * If you would like to get a raw Response object use the other getCampaign function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param campaignId - The ID of the campaign.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type Campaigns.Campaign.
   *
   */
  getCampaign(options?: {
    parameters?: {
      organizationId?: string;
      campaignId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<Campaigns.Campaign>;
  /**
   * Action to get campaign information.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param campaignId - The ID of the campaign.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type Campaigns.Campaign otherwise.
   *
   */
  getCampaign<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        campaignId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : Campaigns.Campaign>;
  /**
   * Updates the campaign with the specified information.
   *
   * If you would like to get a raw Response object use the other updateCampaign function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param campaignId - The ID of the campaign.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type Campaigns.Campaign.
   *
   */
  updateCampaign(options: {
    parameters?: {
      organizationId?: string;
      campaignId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: Campaigns.Campaign;
  }): Promise<Campaigns.Campaign>;
  /**
   * Updates the campaign with the specified information.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param campaignId - The ID of the campaign.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type Campaigns.Campaign otherwise.
   *
   */
  updateCampaign<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        campaignId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: Campaigns.Campaign;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : Campaigns.Campaign>;
  /**
   * Creates a campaign using the information provided.
   *
   * If you would like to get a raw Response object use the other createCampaign function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param campaignId - The ID of the campaign.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type Campaigns.Campaign.
   *
   */
  createCampaign(options: {
    parameters?: {
      organizationId?: string;
      campaignId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: Campaigns.Campaign;
  }): Promise<Campaigns.Campaign>;
  /**
   * Creates a campaign using the information provided.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param campaignId - The ID of the campaign.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type Campaigns.Campaign otherwise.
   *
   */
  createCampaign<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        campaignId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: Campaigns.Campaign;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : Campaigns.Campaign>;
}
